--    FPH Ordering And Estimation
--    Copyright (C) 1999 Aron Rubin
--
--    This program is free software; you can redistribute it and/or modify
--    it under the terms of the GNU General Public License as published by
--    the Free Software Foundation; either version 2 of the License, or
--    (at your option) any later version.
--
--    This program is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--    GNU General Public License for more details.
--
--    You should have received a copy of the GNU General Public License
--    along with this program; if not, write to the Free Software
--    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

CREATE TABLE Customer( i INT UNSIGNED auto_increment primary key, master_i int unsigned,
                       name VARCHAR(50), contact1Name VARCHAR(40), contact1Phone VARCHAR(16),
                       contact1Extension VARCHAR(4), contact1Fax VARCHAR(16), contact1Email VARCHAR(40),
                       contact2Name VARCHAR(40), contact2Phone VARCHAR(16), contact2Extension VARCHAR(4),
                       contact2Fax VARCHAR(16), contact2Email VARCHAR(40),
                       mailingAddress1 VARCHAR(80), mailingAddress2 VARCHAR(80),
                       mailingCity VARCHAR(40), mailingState VARCHAR(40), mailingZip VARCHAR(10),
                       shippingAddress1 VARCHAR(80), shippingAddress2 VARCHAR(80),
                       shippingCity VARCHAR(40), shippingState VARCHAR(40),
                       shippingZip VARCHAR(10), comments TINYTEXT );

CREATE TABLE Product( i INT unsigned auto_increment primary key, master_i INT UNSIGNED,
                      upc VARCHAR(11), name VARCHAR(80), description TINYTEXT,
                      press_i INT UNSIGNED, numColors INT UNSIGNED, varnish CHAR(1),
                      childQuantity INT UNSIGNED, numOut INT UNSIGNED, numFronts INT UNSIGNED,
                      numBacks INT UNSIGNED, paper_i INT UNSIGNED, paper_name VARCHAR(40),
		      paper_type INT UNSIGNED, paper_type_name VARCHAR(40), paper_brand VARCHAR(40),
		      paper_dimentionW DEC(11,3), paper_dimentionL DEC(11,3), paper_lbWeight DEC(11,3),
		      paper_mWeight DEC(11,3), paper_color VARCHAR(40), paper_finish VARCHAR(40),
		      paper_comments TINYTEXT, runWidth DEC(11,3), runHeight DEC(11,3),
		      trimWidth DEC(11,3), trimHeight DEC(11,3), foldWidth DEC(11,3),
		      foldHeight DEC(11,3), format_i INT UNSIGNED, bleed CHAR(1),
		      instructions TINYTEXT );

CREATE TABLE Paper( i INT UNSIGNED auto_increment primary key, name VARCHAR(40),
                    type INT UNSIGNED, brand VARCHAR(40), dimentionW DEC(11,3),
                    dimentionL DEC(11,3), lbWeight DEC(11,3), mWeight DEC(11,3),
                    color VARCHAR(40), finish VARCHAR(32), comments TINYTEXT );

CREATE TABLE PaperType( i INT UNSIGNED auto_increment primary key, name VARCHAR(32) );
-- C1S <=> coated one side
INSERT INTO PaperType( name ) VALUES ( 'Litho C1S' );
INSERT INTO PaperType( name ) VALUES ( 'Bond' );
INSERT INTO PaperType( name ) VALUES ( 'Writing - Bussiness' );
INSERT INTO PaperType( name ) VALUES ( 'Carbonless' );
INSERT INTO PaperType( name ) VALUES ( 'Cast Coated' );
INSERT INTO PaperType( name ) VALUES ( 'Coated Cover' );
INSERT INTO PaperType( name ) VALUES ( 'Uncoated Cover' );
INSERT INTO PaperType( name ) VALUES ( 'Coated Text' );
INSERT INTO PaperType( name ) VALUES ( 'Uncoated Text' );
INSERT INTO PaperType( name ) VALUES ( 'Envelope' );
INSERT INTO PaperType( name ) VALUES ( 'Foil' );
INSERT INTO PaperType( name ) VALUES ( 'Bristol-Index-Tag' );
INSERT INTO PaperType( name ) VALUES ( 'Pressure Sensative - Gummed' );
INSERT INTO PaperType( name ) VALUES ( 'Offset' );
INSERT INTO PaperType( name ) VALUES ( 'Preprinted Material' );
INSERT INTO PaperType( name ) VALUES ( 'Specialty Paper' );
INSERT INTO PaperType( name ) VALUES ( 'Customer Supplied' );

CREATE TABLE PaperFinish( i INT UNSIGNED auto_increment primary key, name VARCHAR(32) );
INSERT INTO PaperFinish( name ) VALUES ( 'Gloss' );

CREATE TABLE Press( i int unsigned auto_increment primary key, name VARCHAR(32) );

CREATE TABLE Plate( i int unsigned auto_increment primary key, product_i int unsigned,
                    color VARCHAR(32), num int unsigned, comments tinytext );

CREATE TABLE OrderHead( i int unsigned auto_increment primary key, customer_i int unsigned,
                        PO VARCHAR(40), orderedOn date, status_i int unsigned,
			billingAddress0 VARCHAR(80), billingAddress1 VARCHAR(80),
			billingAddress2 VARCHAR(80), billingAddress3 VARCHAR(80) );

CREATE TABLE OrderItem( i int unsigned auto_increment primary key, orderHead_i int unsigned,
                        status_i int unsigned, requiredBy date, product_i int unsigned,
                        quantity int unsigned, stockAllocated int unsigned, instructions text );

CREATE TABLE Status( i int unsigned auto_increment primary key, name VARCHAR(32) );
INSERT INTO Status( name ) VALUES ( 'open' );
INSERT INTO Status( name ) VALUES ( 'done' );
INSERT INTO Status( name ) VALUES ( 'cancelled' );
INSERT INTO Status( name ) VALUES ( 'suspended' );

CREATE TABLE Job( i int unsigned auto_increment primary key, product_i int unsigned,
                  customer_i INT UNSIGNED, status_i int unsigned, quantity int unsigned,
		  expectedUse int unsigned, typesetting char(1), typesettingComplete char(1),
		  proof char(1), proofComplete char(1), art char(1), artComplete char(1),
		  plate char(1), plateComplete char(1), instructions text );

CREATE TABLE PrintFormat( i int unsigned auto_increment primary key, name VARCHAR(32) );
INSERT INTO PrintFormat( name ) VALUES ( 'Work in Turn' );
INSERT INTO PrintFormat( name ) VALUES ( 'Sheet Wise' );
INSERT INTO PrintFormat( name ) VALUES ( 'Tumble' );

CREATE TABLE Shipment( i int unsigned auto_increment primary key, customer_i int unsigned,
                       shipBy date, shipMethod_i int unsigned, numCartons int unsigned,
		       shippingAddress0 VARCHAR(80), shippingAddress1 VARCHAR(80),
		       shippingAddress2 VARCHAR(80), shippingAddress3 VARCHAR(80),
		       shippingAddress4 VARCHAR(80), comments TINYTEXT );

CREATE TABLE ShipItem( i int unsigned auto_increment primary key, shipment_i int unsigned,
                       order_i int unsigned, quantity int unsigned );

CREATE TABLE ShipMethod( i int unsigned auto_increment primary key, name VARCHAR(32) );
INSERT INTO ShipMethod( name ) VALUES ( 'FPH Shipping' );
INSERT INTO ShipMethod( name ) VALUES ( 'Carrier Service' );
INSERT INTO ShipMethod( name ) VALUES ( 'Federal Express' );
INSERT INTO ShipMethod( name ) VALUES ( 'UPS' );
INSERT INTO ShipMethod( name ) VALUES ( 'Pick-Up' );
INSERT INTO ShipMethod( name ) VALUES ( 'other' );
